Crate bimm_contracts

BIMM Contracts

Re-exports

pub use bindings::StackEnvironment;
pub use contracts::DimMatcher;
pub use contracts::ShapeContract;
pub use expressions::DimExpr;
pub use shape_argument::ShapeArgument;

Modules

bindings
Evaluation Bindings.
contracts
Shape Contracts.
expressions
Dimension Expressions.
macros
Support Macros.
math
Mathematical utilities.
shape_argument
Shape Argument for passing shapes in a type-safe manner.

Macros

run_every_nth
A macro to run a block of code or an expression every nth time it is called.
shape_contract
Parse a shape contract at compile time and return the ShapePattern struct.