MutableStackMap

Trait MutableStackMap 

pub trait MutableStackMap<'a, V>: StackMap<'a, V>
where V: Default + Copy,
{ // Required method fn bind(&mut self, key: &'a str, value: V); }
A trait for mutable stack-like environments that allows inserting key-value pairs.

Provides no support for removing keys.

Required Methods

fn bind(&mut self, key: &'a str, value: V)

Inserts a key-value pair into the stack.

It is an error to bind a key which is already present; but this is only checked when debug_assertions are on.

Arguments
  • key: The key to insert.
  • value: The value to associate with the key.
Returns

This method does not return a value, but modifies the stack by inserting the key-value pair.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors