Type Alias StackEnvironment
Source pub type StackEnvironment<'a> = &'a [(&'a str, usize)];
Type alias for static/stack compatible bindings.
Looks up a value associated with the given key in the stack.
Read more
Exports the values for the given keys from the local bindings.
Read more