pub struct MutableStackEnvironment<'a> {
pub backing: StackEnvironment<'a>,
pub updates: Vec<(&'a str, usize)>,
}Expand description
A mutable stack environment, backed by a static stack environment.
Fields
backing: StackEnvironment<'a>The backing stack environment that contains the original bindings.
updates: Vec<(&'a str, usize)>The updates made to the stack environment.
Implementations
Sourceimpl<'a> MutableStackEnvironment<'a>
impl<'a> MutableStackEnvironment<'a>
Sourcepub fn new(bindings: StackEnvironment<'a>) -> Self
pub fn new(bindings: StackEnvironment<'a>) -> Self
Creates a new MutableStackEnvironment with the given backing bindings.